==> aws-solutions-constructs.aws-lambda-dynamodb-1.58.0.tar.gz: aws-solutions-constructs.aws-lambda-dynamodb-1.58.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-lambda-dynamodb",
    "version": "1.58.0",
    "description": "CDK Constructs for AWS Lambda to AWS DynamoDB integration.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_lambda_dynamodb",
        "aws_solutions_constructs.aws_lambda_dynamodb._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_lambda_dynamodb._jsii": [
            "aws-lambda-dynamodb@1.58.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_lambda_dynamodb": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.10.0, <2.0.0",
        "publication>=0.0.3",
        "aws-cdk.aws-dynamodb>=1.58.0, <1.59.0",
        "aws-cdk.aws-lambda>=1.58.0, <1.59.0",
        "aws-cdk.core>=1.58.0, <1.59.0",
        "aws-solutions-constructs.core>=1.58.0, <1.59.0",
        "constructs>=3.0.2, <4.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-lambda-dynamodb-1.59.0.tar.gz: aws-solutions-constructs.aws-lambda-dynamodb-1.59.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-lambda-dynamodb",
    "version": "1.59.0",
    "description": "CDK Constructs for AWS Lambda to AWS DynamoDB integration.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_lambda_dynamodb",
        "aws_solutions_constructs.aws_lambda_dynamodb._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_lambda_dynamodb._jsii": [
            "aws-lambda-dynamodb@1.59.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_lambda_dynamodb": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-dynamodb>=1.59.0, <1.60.0",
        "aws-cdk.aws-lambda>=1.59.0, <1.60.0",
        "aws-cdk.core>=1.59.0, <1.60.0",
        "aws-solutions-constructs.core>=1.59.0, <1.60.0",
        "constructs>=3.0.2, <4.0.0",
        "jsii>=1.11.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "License :: OSI Approved"
    ]
}
"""
)

with open("README.md") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
